netapp_ontap.resources.account API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.account`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

This API displays and manages the configuration of scoped user accounts.

Newly created user accounts might need to be updated for many reasons. For example, a user account might need to use a different application or its role might need to be modified. According to a policy, the password or authentication source of a user account might need to be changed, or a user account might need to be locked or deleted from the system. This API allows you to make these changes to user accounts.

Specify the owner UUID and the user account name in the URI path. The owner UUID corresponds to the UUID of the SVM for which the user account has been created and can be obtained from the response body of the GET request performed on one of the following APIs: /api/security/accounts for all user accounts /api/security/accounts/?scope=cluster for cluster-scoped user accounts /api/security/accounts/?scope=svm for SVM-scoped accounts /api/security/accounts/?owner.name= for a specific SVM This API response contains the complete URI for each user account that can be used.

## Examples

### Retrieving the user account details

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Account

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Account(
            name="svm_user1", **{"owner.uuid": "aef7c38-4bd3-11e9-b238-0050568e2e25"}
        )
        resource.get()
        print(resource)

Try it out

    Account(
        {
            "scope": "svm",
            "role": {
                "_links": {
                    "self": {
                        "href": "/api/svms/aaef7c38-4bd3-11e9-b238-0050568e2e25/admin/roles/vsadmin"
                    }
                },
                "name": "vsadmin",
            },
            "_links": {
                "self": {
                    "href": "/api/security/accounts/aaef7c38-4bd3-11e9-b238-0050568e2e25/svm_user1"
                }
            },
            "name": "svm_user1",
            "owner": {
                "name": "svm1",
                "uuid": "aaef7c38-4bd3-11e9-b238-0050568e2e25",
                "_links": {
                    "self": {"href": "/api/svm/svms/aaef7c38-4bd3-11e9-b238-0050568e2e25"}
                },
            },
            "applications": [
                {
                    "application": "ssh",
                    "authentication_methods": ["password"],
                    "second_authentication_method": "none",
                }
            ],
            "locked": False,
        }
    )

### Updating the applications and role in a user account

Specify the desired configuration in the form of tuples (of applications and authentication methods) and the role. All other previously configured applications that are not specified in the "applications" parameter of the PATCH request will be de-provisioned for the user account.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Account

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Account(
            name="svm_user1", **{"owner.uuid": "aaef7c38-4bd3-11e9-b238-0050568e2e25"}
        )
        resource.applications = [
            {"application": "http", "authentication_methods": ["domain"]},
            {"application": "ontapi", "authentication_methods": ["password"]},
        ]
        resource.role.name = "vsadmin-backup"
        resource.patch()

### Updating the password for a user account

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Account

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Account(
            name="svm_user1", **{"owner.uuid": "aaef7c38-4bd3-11e9-b238-0050568e2e25"}
        )
        resource.password = "newp@ssw@rd2"
        resource.patch()

### Locking a user account

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Account

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Account(
            name="svm_user1", **{"owner.uuid": "aaef7c38-4bd3-11e9-b238-0050568e2e25"}
        )
        resource.locked = True
        resource.patch()

### Deleting a user account

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Account

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Account(
            name="svm_user1", **{"owner.uuid": "aaef7c38-4bd3-11e9-b238-0050568e2e25"}
        )
        resource.delete()

## Classes

`class Account (*args, **kwargs)`

  Allows interaction with Account objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves a list of user accounts in the cluster.

    ### Related ONTAP commands

    - `security login show`

    ### Learn more

    - `DOC /security/accounts`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a user account.

    ### Required parameters

    - `name` - Account name to be deleted.
    - `owner.uuid` - UUID of the SVM housing the user account to be deleted.

    ### Related ONTAP commands

    - `security login delete`

    ### Learn more

    - `DOC /security/accounts/{owner.uuid}/{name}`
    - `DOC /security/accounts`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves a list of user accounts in the cluster.

    ### Related ONTAP commands

    - `security login show`

    ### Learn more

    - `DOC /security/accounts`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves a list of user accounts in the cluster.

    ### Related ONTAP commands

    - `security login show`

    ### Learn more

    - `DOC /security/accounts`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates a user account. Locks or unlocks a user account and/or updates the role, applications, and/or password for the user account.

    ### Required parameters

    - `name` - Account name to be updated.
    - `owner.uuid` - UUID of the SVM housing the user account to be updated.

    ### Optional parameters

    - `applications` - Array of one or more tuples (of application and authentication methods).
    - `role` - RBAC role for the user account.
    - `password` - Password for the user account (if the authentication method is opted as password for one or more of applications).
    - `second_authentication_method` - Needed for MFA and only supported for ssh application. Defaults to `none` if not supplied.
    - `comment` - Comment for the user account (e.g purpose of this account).
    - `locked` - Set to true/false to lock/unlock the account.

    ### Related ONTAP commands

    - `security login create`
    - `security login modify`
    - `security login password`
    - `security login lock`
    - `security login unlock`

    ### Learn more

    - `DOC /security/accounts/{owner.uuid}/{name}`
    - `DOC /security/accounts`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes a user account.

    ### Required parameters

    - `name` - Account name to be deleted.
    - `owner.uuid` - UUID of the SVM housing the user account to be deleted.

    ### Related ONTAP commands

    - `security login delete`

    ### Learn more

    - `DOC /security/accounts/{owner.uuid}/{name}`
    - `DOC /security/accounts`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves a specific user account.

    ### Related ONTAP commands

    - `security login show`

    ### Learn more

    - `DOC /security/accounts/{owner.uuid}/{name}`
    - `DOC /security/accounts`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates a user account. Locks or unlocks a user account and/or updates the role, applications, and/or password for the user account.

    ### Required parameters

    - `name` - Account name to be updated.
    - `owner.uuid` - UUID of the SVM housing the user account to be updated.

    ### Optional parameters

    - `applications` - Array of one or more tuples (of application and authentication methods).
    - `role` - RBAC role for the user account.
    - `password` - Password for the user account (if the authentication method is opted as password for one or more of applications).
    - `second_authentication_method` - Needed for MFA and only supported for ssh application. Defaults to `none` if not supplied.
    - `comment` - Comment for the user account (e.g purpose of this account).
    - `locked` - Set to true/false to lock/unlock the account.

    ### Related ONTAP commands

    - `security login create`
    - `security login modify`
    - `security login password`
    - `security login lock`
    - `security login unlock`

    ### Learn more

    - `DOC /security/accounts/{owner.uuid}/{name}`
    - `DOC /security/accounts`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates a new user account.

    ### Required parameters

    - `name` - Account name to be created.
    - `applications` - Array of one or more application tuples (of application and authentication methods).

    ### Optional parameters

    - `owner.name` or `owner.uuid` - Name or UUID of the SVM for an SVM-scoped user account. If not supplied, a cluster-scoped user account is created.
    - `role` - RBAC role for the user account. Defaulted to `admin` for cluster user account and to `vsadmin` for SVM-scoped account.
    - `password` - Password for the user account (if the authentication method is opted as password for one or more of applications).
    - `second_authentication_method` - Needed for MFA and only supported for ssh application. Defaults to `none` if not supplied.
    - `comment` - Comment for the user account (e.g purpose of this account).
    - `locked` - Locks the account after creation. Defaults to `false` if not supplied.

    ### Related ONTAP commands

    - `security login create`

    ### Learn more

    - `DOC /security/accounts`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class AccountSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Account object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `applications GET POST PATCH`

    The applications field of the account.

  `comment GET POST PATCH`

    Optional comment for the user account.

  `links GET`

    The links field of the account.

  `locked GET POST PATCH`

    Locked status of the account.

  `name GET POST`

    User or group account name

    Example: joe.smith

  `owner GET POST`

    The owner field of the account.

  `password POST PATCH`

    Password for the account. The password can contain a mix of lower and upper case alphabetic characters, digits, and special characters.

  `role GET POST PATCH`

    The role field of the account.

  `scope GET`

    Scope of the entity. Set to "cluster" for cluster owned objects and to "svm" for SVM owned objects.

    Valid choices:

    - cluster
    - svm